Index: third_party/WebKit/public/web/WebFrameSerializer.h |
diff --git a/third_party/WebKit/public/web/WebPageSerializer.h b/third_party/WebKit/public/web/WebFrameSerializer.h |
similarity index 92% |
rename from third_party/WebKit/public/web/WebPageSerializer.h |
rename to third_party/WebKit/public/web/WebFrameSerializer.h |
index 44d5f94fb12b387a63a990f8500f02f9b824083c..051ed08443a5eb84fe8ae589a54cba7b41842300 100644 |
--- a/third_party/WebKit/public/web/WebPageSerializer.h |
+++ b/third_party/WebKit/public/web/WebFrameSerializer.h |
@@ -28,8 +28,8 @@ |
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
*/ |
-#ifndef WebPageSerializer_h |
-#define WebPageSerializer_h |
+#ifndef WebFrameSerializer_h |
+#define WebFrameSerializer_h |
#include "../platform/WebCString.h" |
#include "../platform/WebCommon.h" |
@@ -42,14 +42,13 @@ |
namespace blink { |
-class WebPageSerializerClient; |
+class WebFrameSerializerClient; |
class WebFrame; |
class WebLocalFrame; |
template <typename T> class WebVector; |
// Serialization of frame contents into html or mhtml. |
-// TODO(lukasza): Rename this class to WebFrameSerializer? |
-class WebPageSerializer { |
+class WebFrameSerializer { |
public: |
// Generates and returns an MHTML header. |
// |
@@ -95,25 +94,25 @@ public: |
BLINK_EXPORT static WebData generateMHTMLFooter(const WebString& boundary); |
// IMPORTANT: |
// The API below is an older implementation of a pageserialization that |
// will be removed soon. |
// This function will serialize the specified frame to HTML data. |
// We have a data buffer to temporary saving generated html data. We will |
// sequentially call WebPageSerializerClient once the data buffer is full. |
// |
// Return false means if no data has been serialized (i.e. because |
// the target frame didn't have a valid url). |
// |
// The parameter frame specifies which frame need to be serialized. |
// The parameter client specifies the pointer of interface |
// WebPageSerializerClient providing a sink interface to receive the |
// individual chunks of data to be saved. |
// The parameter urlsToLocalPaths contains a mapping between original URLs |
// of saved resources and corresponding local file paths. |
BLINK_EXPORT static bool serialize( |
WebLocalFrame*, |
- WebPageSerializerClient*, |
+ WebFrameSerializerClient*, |
const WebVector<std::pair<WebURL, WebString>>& urlsToLocalPaths); |
// FIXME: The following are here for unit testing purposes. Consider |
@@ -95,25 +94,25 @@ public: |
BLINK_EXPORT static WebData generateMHTMLFooter(const WebString& boundary); |
// IMPORTANT: |
- // The API below is an older implementation of a pageserialization that |
+ // The API below is an older implementation of frame serialization that |
// will be removed soon. |
// This function will serialize the specified frame to HTML data. |
@@ -95,25 +94,25 @@ public: |
// This function will serialize the specified frame to HTML data. |
// We have a data buffer to temporary saving generated html data. We will |
- // sequentially call WebPageSerializerClient once the data buffer is full. |
+ // sequentially call WebFrameSerializerClient once the data buffer is full. |
// |
// Return false means if no data has been serialized (i.e. because |
@@ -95,25 +94,25 @@ public: |
// The parameter frame specifies which frame need to be serialized. |
// The parameter client specifies the pointer of interface |
- // WebPageSerializerClient providing a sink interface to receive the |
+ // WebFrameSerializerClient providing a sink interface to receive the |
// individual chunks of data to be saved. |
// The parameter urlsToLocalPaths contains a mapping between original URLs |